@@ -33,6 +33,8 @@ class EvalHook(_EvalHook):
                  **kwargs):
         super().__init__(*args, by_epoch=by_epoch, **kwargs)
         self.pre_eval = pre_eval
+        self.latest_results = None
+
         if efficient_test:
             warnings.warn(
                 'DeprecationWarning: ``efficient_test`` for evaluation hook '
@@ -48,6 +50,7 @@ class EvalHook(_EvalHook):
         from mmseg.apis import single_gpu_test
         results = single_gpu_test(
             runner.model, self.dataloader, show=False, pre_eval=self.pre_eval)
+        self.latest_results = results
         runner.log_buffer.clear()
         runner.log_buffer.output['eval_iter_num'] = len(self.dataloader)
         key_score = self.evaluate(runner, results)
@@ -80,6 +83,7 @@ class DistEvalHook(_DistEvalHook):
                  **kwargs):
         super().__init__(*args, by_epoch=by_epoch, **kwargs)
         self.pre_eval = pre_eval
+        self.latest_results = None
         if efficient_test:
             warnings.warn(
                 'DeprecationWarning: ``efficient_test`` for evaluation hook '
@@ -116,7 +120,7 @@ class DistEvalHook(_DistEvalHook):
             tmpdir=tmpdir,
             gpu_collect=self.gpu_collect,
             pre_eval=self.pre_eval)
-
+        self.latest_results = results
         runner.log_buffer.clear()
 
         if runner.rank == 0:
